<?php
/**
 * Display list of pages with its childs.
 */
class Smallbiz_Front_Page_Grid_Widget extends WP_Widget {

	/**
	 * Sets up the widgets.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function __construct() {

		// Set up the widget options.
		$widget_ops = array(
			'classname'   => 'widget_fp_grid',
			'description' => esc_html__( 'Use this widget only in Front Page Top sidebar. Display page with its child pages.', 'smallbiz' ),
			'customize_selective_refresh' => true
		);

		// Create the widget.
		parent::__construct(
			'smallbiz-fp-grid',                                    // $this->id_base
			esc_html__( 'Smallbiz - Featured Pages', 'smallbiz' ), // $this->name
			$widget_ops                                            // $this->widget_options
		);

		$this->alt_option_name = 'widget_fp_grid';

	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $args     Display arguments including 'before_title', 'after_title',
	 *                        'before_widget', and 'after_widget'.
	 * @param array $instance Settings for the current Recent Posts widget instance.
	 */
	public function widget( $args, $instance ) {
		if ( ! isset( $args['widget_id'] ) ) {
			$args['widget_id'] = $this->id;
		}

		// Set up default value
		$page_id = ( ! empty( $instance['page_id'] ) ) ? absint( $instance['page_id'] ) : '';
		$number  = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 3;
		$column  = isset( $instance['column'] ) ? $instance['column'] : 'three-columns';

		// Hide if no page selected
		if ( $page_id ) :

			// Output the theme's $before_widget wrapper.
			echo $args['before_widget'];

				// Display the data
				$child_pages = new WP_Query( array(
					'post_type'      => 'page',
					'orderby'        => 'menu_order',
					'order'          => 'ASC',
					'post_parent'    => $page_id,
					'posts_per_page' => $number,
					'no_found_rows'  => true,
				) );

				if ( $child_pages->have_posts() ) : ?>

					<div class="grid-area">
						<div class="container">

							<?php while ( $child_pages->have_posts() ) : $child_pages->the_post(); ?>

								<div class="grid <?php echo sanitize_html_class( $column ); ?>">
									<?php get_template_part( 'partials/content', 'grid' ); ?>
								</div><!-- .grid -->

							<?php endwhile; ?>

						</div><!-- .container -->
					</div><!-- .grid-area -->

				<?php
				endif; wp_reset_postdata();

			// Close the theme's widget wrapper.
			echo $args['after_widget'];

		endif;

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $new_instance New settings for this instance as input by the user via
	 *                            WP_Widget::form().
	 * @param array $old_instance Old settings for this instance.
	 * @return array Updated settings to save.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance               = $old_instance;
		$instance['page_id']    = absint( $new_instance['page_id'] );
		$instance['number']     = absint( $new_instance['number'] );
		$instance['column']     = isset( $new_instance['column'] ) ? esc_attr( $new_instance['column'] ) : 'three-columns';
		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $instance Current settings.
	 */
	public function form( $instance ) {
		$page_id    = isset( $instance['page_id'] ) ? absint( $instance['page_id'] ) : '';
		$number     = isset( $instance['number'] ) ? absint( $instance['number'] ) : 3;
		$column     = isset( $instance['column'] ) ? esc_attr( $instance['column'] ) : 'three-columns';
	?>

		<p>
			<label for="<?php echo $this->get_field_id( 'page_id' ); ?>">
				<?php esc_html_e( 'Parent Page: ', 'smallbiz' ); ?>
			</label>
			<?php
				wp_dropdown_pages(
					array(
						'show_option_none' => esc_html__( 'Select a parent page', 'smallbiz' ),
						'name'             => $this->get_field_name( 'page_id' ),
						'selected'         => $page_id
					)
				);
			?>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'number' ); ?>">
				<?php esc_html_e( 'Number of child pages to show: ', 'smallbiz' ); ?>
			</label>
			<input class="tiny-text" id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" type="number" step="1" min="1" value="<?php echo $number; ?>" size="3" />
		</p>

		<p>
			<label for=""><?php esc_html_e( 'Column:', 'smallbiz' ); ?></label>
			<ul>
				<li>
					<input class="radio" type="radio" value="three-columns" <?php checked( $column, 'three-columns' ); ?> id="<?php echo $this->get_field_id( 'column' ); ?>-three-columns" name="<?php echo $this->get_field_name( 'column' ); ?>" />
					<label for="<?php echo $this->get_field_id( 'column' ); ?>-three-columns">
						<?php esc_html_e( 'Three Columns', 'smallbiz' ); ?>
					</label>
				</li>
				<li>
					<input class="radio" type="radio" value="two-columns" <?php checked( $column, 'two-columns' ); ?> id="<?php echo $this->get_field_id( 'column' ); ?>-two-columns" name="<?php echo $this->get_field_name( 'column' ); ?>" />
					<label for="<?php echo $this->get_field_id( 'column' ); ?>-two-columns">
						<?php esc_html_e( 'Two Columns', 'smallbiz' ); ?>
					</label>
				</li>
			</ul>
		</p>

	<?php

	}

}
